;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#x3702d4403b4d0b146f3a437525cfd4c0 . "./code.cg2js/cg-acache.fasl")
(#x6e56b1e849bb7ed45014907745d4e911 . "./code.cg2js/cg-base.fasl")
(#x8646a57fc06e4a7dee4cd9d4e6efc612 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#xa72cb2f381101cb7271f01050cb2b01c . "./code.cg2js/cg-bitmap-pane.fasl")
(#x0d0ff6d06a9a84672eb83306f60ea0fd . "./code.cg2js/cg-bitmap-stream.fasl")
(#xecd04c762e9e8d2c6346d765269b1026 . "./code.cg2js/cg-button.fasl")
(#x110ca8ed2a477c5e454acfb17afde41f . "./code.cg2js/cg-calendar.fasl")
(#x0b0cd123c8fc87fad37e3f538beedc7c . "./code.cg2js/cg-caret.fasl")
(#x97b22ded0b79e30dc065558f938d0934 . "./code.cg2js/cg-chart-or-plot.fasl")
(#x7e8c59403077d3433df01bde5a69af63 . "./code.cg2js/cg-chart-widget.fasl")
(#xa3c022ba870a21c3eb2c0b1d327762c0 . "./code.cg2js/cg-check-box.fasl")
(#xbd57515528e715805b83e3df3c6258cc . "./code.cg2js/cg-choice-list.fasl")
(#x55e671c875b28298464ed7e4652e5f06 . "./code.cg2js/cg-choose-printer.fasl")
(#x491f68aedf9394a657518aa216cf42b9 . "./code.cg2js/cg-class-grid.fasl")
(#x8db2dac1d56657fb83ede30a39035bc5 . "./code.cg2js/cg-class-slot-grid.fasl")
(#x24a1ff3fa384f51f7a2fe2e4bb3a4135 . "./code.cg2js/cg-class-support.fasl")
(#x417e21212551ed90ad14a11678b54953 . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#x4ba585763869a93660611081c1d24d06 . "./code.cg2js/cg-clipboard-stack.fasl")
(#xeb96bb65cbb962926d9fe32eebd16a08 . "./code.cg2js/cg-clipboard.fasl")
(#x36db86fdce180321c401c7c16e34be0b . "./code.cg2js/cg-color-dialog.fasl")
(#x563a71e124c3c357589cdfc8a6aed3e1 . "./code.cg2js/cg-combo-box.fasl")
(#xa9c3cfdb6d18405d2a59ee132dd31159 . "./code.cg2js/cg-common-control.fasl")
(#x057b750af890f5fd32f6f5bd6df82819 . "./code.cg2js/cg-comtab.fasl")
(#x4d5bac91869f2f5b603934ec620bcf30 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#x5570086bc170f334b0b262e53b164860 . "./code.cg2js/cg-curve.fasl")
(#x2ee7f91c76809f345cf1506b4b96f58b . "./code.cg2js/cg-dde-utils.fasl")
(#x1cc9ff48350754ce76b840bd64c99e98 . "./code.cg2js/cg-dev.fasl")
(#x4149def7d78f68818f4ec7f0a98970d5 . "./code.cg2js/cg-dialog-item.fasl")
(#xffc4713c642c686a3318a2abefd81566 . "./code.cg2js/cg-directory-dialog-os.fasl")
(#x17951a0e9847a0704e221cbaae166ec5 . "./code.cg2js/cg-directory-dialog.fasl")
(#xec3174c5b86f8f674851c3aa3fd95b97 . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#x47dea2a42f64c0989f4a134eaf38ffa8 . "./code.cg2js/cg-drag-and-drop.fasl")
(#x1db524ee875dfff11362a112d30524dd . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x9e01e889938afb17d507d2620e15c617 . "./code.cg2js/cg-drawable.fasl")
(#xaf9261dbd363e9336a65c84dbc834ae4 . "./code.cg2js/cg-dropping-outline.fasl")
(#xa4e47e7fb470082ba1f31f5a6f5d1507 . "./code.cg2js/cg-edit-in-place.fasl")
(#xdc9c03b8342e4b97b2986ac6a1ea7654 . "./code.cg2js/cg-editable-text.fasl")
(#xf86cc9ef445a664241fb8e32fcc17a6c . "./code.cg2js/cg-file-dialog.fasl")
(#x025f94a441f123ebe62717721b860e84 . "./code.cg2js/cg-fill-texture.fasl")
(#x88c9e0561e2b4922d470fb913010dfed . "./code.cg2js/cg-find-string-dialog.fasl")
(#x1025923e83237f6663ad93def6db38f8 . "./code.cg2js/cg-font-dialog.fasl")
(#xba8961969b27fbc6456bba73ce2924f0 . "./code.cg2js/cg-gesture-emulation.fasl")
(#x8f4608a02d6c30569c3554ad8de41c82 . "./code.cg2js/cg-get-pixmap.fasl")
(#xc3699a1e668654ec4606224c5b0d8e70 . "./code.cg2js/cg-get-position.fasl")
(#x695757c5a7cb46e7f933fb8c733f41d2 . "./code.cg2js/cg-graphics-context.fasl")
(#xc0d409629d48758ba28d909785bcf45a . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#x1fb03542cd822419522758c81386d208 . "./code.cg2js/cg-grid-widget.fasl")
(#xa68dd05da8195cf700ae2bddf4b51119 . "./code.cg2js/cg-group-box.fasl")
(#x1add4a5f8e95458c41247ee864ee89e6 . "./code.cg2js/cg-header-control.fasl")
(#xa83eccebd24cf25edc1911a8167bb0e0 . "./code.cg2js/cg-hotspot.fasl")
(#xc9ea718fa365eed92cf40a97a90b3fca . "./code.cg2js/cg-html-dialog.fasl")
(#xa158b0f5a620a1cc8d9169f4aab9ba30 . "./code.cg2js/cg-html-widget.fasl")
(#x92b14adf451604c3de44a5cc35a83fab . "./code.cg2js/cg-icon-pixmap.fasl")
(#xa05b7374417f40cff0f68e3d9bb2569e . "./code.cg2js/cg-icon.fasl")
(#xf106750ebaa1260abc26df9fbe0cbfd5 . "./code.cg2js/cg-ie.fasl")
(#x40bc3eee3c1b5a61860f9ae41af8ab3b . "./code.cg2js/cg-intersect-posbox.fasl")
(#xe7f4e9c8030e8f300517aee6f72563c7 . "./code.cg2js/cg-intersect.fasl")
(#x74d09b7e493d0d263957fd5ea9727ea2 . "./code.cg2js/cg-item-list.fasl")
(#x24f3da4c811891ec733e07fdfc8dc090 . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x2ee4ca45dc0469b7e409f0a2f0c0a840 . "./code.cg2js/cg-lamp.fasl")
(#xf26af861125a6cc26da5fc23891896c3 . "./code.cg2js/cg-layout.fasl")
(#xd8e5470ec812ac853b2b6e044ba02590 . "./code.cg2js/cg-lettered-menu.fasl")
(#x4e9232b805dfc45fc6421382177e27ab . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#xb9d5eb684a0c36c9d38420929f1721b4 . "./code.cg2js/cg-lisp-text.fasl")
(#x87ed4b95a27bedce248b117175a3b061 . "./code.cg2js/cg-lisp-widget.fasl")
(#x2981728e2232595ac47087246fc6e8f5 . "./code.cg2js/cg-list-view.fasl")
(#xc54a61f893808c818f9d9b454325b543 . "./code.cg2js/cg-mci.fasl")
(#x823505c42bdc543398019ca3459a102d . "./code.cg2js/cg-menu-tooltip.fasl")
(#x54570fc6c3aceabf8565e0f0a9c5beae . "./code.cg2js/cg-menu.fasl")
(#xce7ad7db6ae55bc9e112f4a163cd7571 . "./code.cg2js/cg-message-dialog.fasl")
(#x34872da95b726da3472a9f1a81831474 . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x6cb02911a3464647240c28fb0f8b0eb3 . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#xdda73c04730f2bb8653ac7ce442be8a4 . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#xff92483a2c621eaa6639c6c66ee49535 . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#x906f9542d9823583774913ae3a8e4010 . "./code.cg2js/cg-multi-picture-button.fasl")
(#x72b7a8006b58d758d81c98df8bbbeffc . "./code.cg2js/cg-nodes.fasl")
(#x5ba27fc38507f967f96214d53635f979 . "./code.cg2js/cg-object-editor-layout.fasl")
(#xde8b7913d1a0c6469b9c5e83775122c3 . "./code.cg2js/cg-object-editor.fasl")
(#x7832b8baa724888670164037d4df66c0 . "./code.cg2js/cg-ocx.fasl")
(#x4bf6fb684c7fc75707ce5fd3fd6968db . "./code.cg2js/cg-os-widget.fasl")
(#x5a4b32c6d2437bbdb9b0a5ed53a2b83a . "./code.cg2js/cg-os-window.fasl")
(#xe3cd67aca6cc15991c604febcda96902 . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x5b4ecec7f8256394da12dde0cb20d6e3 . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x6f9be628495583324e7f6d9f68ea399b . "./code.cg2js/cg-outline.fasl")
(#xfd204b020769e38ee3683af0da0303da . "./code.cg2js/cg-palette.fasl")
(#xc36edf3d2385c4430d4ad730360ae81a . "./code.cg2js/cg-paren-matching.fasl")
(#xe2fa7e7c5c674532389c6c9f47c1343c . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x39360c6a349343cc37907ba29fd0732a . "./code.cg2js/cg-picture-widget.fasl")
(#x5a8db35a3d2eaae9fedafd9b9680f915 . "./code.cg2js/cg-pixmap-file-io.fasl")
(#xa243acff15d66dc9a7d7860e4edd1168 . "./code.cg2js/cg-pixmap-printing.fasl")
(#x46a830a13f9eed85b13612b93583027a . "./code.cg2js/cg-pixmap-rotate.fasl")
(#x56b17a17789130c9e655a4eaec55fa77 . "./code.cg2js/cg-pixmap-widget.fasl")
(#x5c129dfb4b13547f2be585bf1787cb52 . "./code.cg2js/cg-pixmap.fasl")
(#x664449ac9c91f85f4930cf7a327f8200 . "./code.cg2js/cg-plot-widget.fasl")
(#xb5f0077764d97a7b5a6079b8fd5c8f54 . "./code.cg2js/cg-printing.fasl")
(#x1a25cb5822c887d8a874411e53256d63 . "./code.cg2js/cg-progress-indicator.fasl")
(#xa582ba9206a53c7914ed15c5aac6eacf . "./code.cg2js/cg-project-window.fasl")
(#x700cb8ee391f40bdaf2ea1e1534930d8 . "./code.cg2js/cg-property.fasl")
(#x7c17bb641845057de8b2e2c1f00eb1a6 . "./code.cg2js/cg-radio-button.fasl")
(#xfaac2bd6457312940a6324988f8ad6b2 . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#xd268bed5249d3a4d354780bf54c43cf5 . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#x5ac58972cccf625ae3c192e096aabf6c . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x09d78425ae7fcef2cabddf77246f71b5 . "./code.cg2js/cg-rich-edit.fasl")
(#xc0508c7fe42ee6e18210d377f9a9e618 . "./code.cg2js/cg-sample-file-menu.fasl")
(#x76202fedfcf7cc60733a12c2cbd6ce00 . "./code.cg2js/cg-scaling-stream.fasl")
(#x97515b9525458fddc6334e37d0737cf5 . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#x2f602d064d475e21ac5f5ee7b99dad9a . "./code.cg2js/cg-scroll-bar.fasl")
(#x64eabe4ba4316259f378e8f2ced72df2 . "./code.cg2js/cg-scrolling-static-text.fasl")
(#x3d8ca703ca4642ef4bf2c3e31c2e92bc . "./code.cg2js/cg-selected-object.fasl")
(#x019b3ff5356ea41bf95a1339cf30b5cf . "./code.cg2js/cg-shortcut-menu.fasl")
(#xd24ddfdb7bb60d59d45bd529e55d6e70 . "./code.cg2js/cg-split-bar.fasl")
(#x33bfff473ed31da6a45d3aca553c670a . "./code.cg2js/cg-static-text.fasl")
(#xcf3b8e2ff44ea7d100284f94af4fe1b6 . "./code.cg2js/cg-status-bar.fasl")
(#x21e08c594890ef84addb32c663cb6059 . "./code.cg2js/cg-string-dialog.fasl")
(#x49f68834d75f71fbf361a565c4b7be3c . "./code.cg2js/cg-tab-control.fasl")
(#x198d988ff02c182d4062aa1a426860de . "./code.cg2js/cg-template-string.fasl")
(#xf6cae1f5f11ff3948eff56cf32debf81 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#x38c303114def7e404d8f8df1e8fbd197 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#xf66c01e9723dbef2f835b413c239950c . "./code.cg2js/cg-text-edit-pane.fasl")
(#x05ba8983a6a6442e55c712017586f262 . "./code.cg2js/cg-text-or-combo.fasl")
(#xdd5cd575687a634a789494e75a88fcbb . "./code.cg2js/cg-text-widget.fasl")
(#x635de9b341f08ae8cae37bdeea981cdd . "./code.cg2js/cg-timer.fasl")
(#xb100cab4923d0414300ab4fbd175afa9 . "./code.cg2js/cg-toggling-widget.fasl")
(#x8d079e46655a50f9f3d9a4db979aa5c9 . "./code.cg2js/cg-toolbar.fasl")
(#x98553b80dcb49e02e229764c02049794 . "./code.cg2js/cg-tooltip.fasl")
(#x6cba49f16fe784dcd2651f79afdb62fa . "./code.cg2js/cg-touch.fasl")
(#x22291e29262d973c4c1651a61520bcb6 . "./code.cg2js/cg-trackbar.fasl")
(#xf87169d4291aafae872b5e1bf1df29f9 . "./code.cg2js/cg-tray.fasl")
(#x3afe6049c3592cf0eb298fa5eb9389a7 . "./code.cg2js/cg-up-down-control.fasl")
(#xa84e1911f18821e1e228df7f32de49c2 . "./code.cg2js/cg-utility-dialog.fasl")
(#x0090b731f17385a14df068524669881a . "./code.cg2js/cg-web-browser-dde.fasl")
(#xf050e2bb1f65d99e135b2ef2df56c533 . "./code.cg2js/cg-web-browser.fasl")
(#x0f362d69d4e8be922039884f50bc7295 . "./code.cg2js/cg-wrap-string.fasl")
(#x064ebddbecc6e47a325723cd761ac909 . "./code.cg2js/cg-yes-no-list.fasl")
(#xc4a730583f73a401f8fbb658853c9565 . "./code.cg2js/cg-yes-no-string.fasl")
(#x04745190b6dd387747a95eb93092f4ed . "./code.cg2js/cg.fasl")
(#x29aadb8a3bf3e29d38da38e9aebdb241 . "./code.idejs/ide-acache.fasl")
(#x43b4e24e6a8d79e239ee7783059b43e8 . "./code.idejs/ide-apropos.fasl")
(#x2c5c67cef999b06b0191df77f318b2ba . "./code.idejs/ide-base.fasl")
(#xf4ddf273617309270c924f597fe3963d . "./code.idejs/ide-class-browser.fasl")
(#x2150b6e0376393057bc0783afa448a67 . "./code.idejs/ide-class-grapher.fasl")
(#xf70308dcc79b4894b4d30c6f528a940d . "./code.idejs/ide-clipboard.fasl")
(#xbd158eb3999332e991c45d32298551d2 . "./code.idejs/ide-dev.fasl")
(#xc2a65367f498401a8266bf47233629c5 . "./code.idejs/ide-editor.fasl")
(#x0ca5f286faba115b7300241a2096c73b . "./code.idejs/ide-find-definitions.fasl")
(#x2f3f0fae0f24090e472465e12fb3ed86 . "./code.idejs/ide-find-in-files.fasl")
(#xc47a64086fdcfd3357d92cafad88b604 . "./code.idejs/ide-form.fasl")
(#x8a4795f022d83e4e3ef7b260d1a2e4a4 . "./code.idejs/ide-grapher.fasl")
(#xb9e4160dda099e65087f83cd2f169a15 . "./code.idejs/ide-inspector.fasl")
(#x990368c6edc1184e582531216afa8cb5 . "./code.idejs/ide-intro.fasl")
(#x3b1d4fa9bcd14c12f0542ffd86fe57f4 . "./code.idejs/ide-keyshort.fasl")
(#xd78e0e69f441c233972a61180f200291 . "./code.idejs/ide-navigator.fasl")
(#x1fa470a78d7546f2fc2636200656ff66 . "./code.idejs/ide-package-list.fasl")
(#x39ce2a0b61921940600673fe0b97c77c . "./code.idejs/ide-patch-dialog.fasl")
(#x3c89c570836f9f1cdf01d4736db53830 . "./code.idejs/ide-process-browser.fasl")
(#x67775a5abac024aa554d348935e96488 . "./code.idejs/ide-project.fasl")
(#x91cfd113056fdd15ed57d59699fd1688 . "./code.idejs/ide-trace.fasl")
(#xf72c73166b27dbc4cae55a1ea2870264 . "./code.idejs/ide-window-list.fasl")
(#xdc9be004bb9ea6ecb55ad1944e7ba7c0 . "./code.idejs/ide.fasl")
(#xdf73f3983b983ba8030e7ee4702b498a . "./cgjs.html")
(#xa0fd27890288fb85b9ee621ed47b2251 . "./ssl-not-found.html")
(#x4e1b21622d7d9cc4e6fc09c7875f8430 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
